#define HAVE_PTHREAD
#define FANCY_PAGE_TABLES
#define HAVE_POSIX_SHM
#define HAVE_POSIX_SEM_ANON
#define HAVE_POSIX_SEM_NAMED
#define HAVE_POSIX_SPAWN
#define HAVE_POSIX_FADVISE
#define HAVE_POSIX_FALLOCATE
#define HAVE_POSIX_MEMALIGN
#define HAVE_SYSLOG
#define HAVE_AT
#define HAVE_FCHDIR
#define HAVE_FDOPENDIR
#define HAVE_REALPATH
#define HAVE_PTY
#define HAVE_PTY_OPENPT
#define HAVE_INITGROUPS
#define HAVE_CLOCK
#define HAVE_POSIX_TIMER
#define HAVE_EVENTFD
#define HAVE_TIMERFD
#define HAVE_EPOLL
#define HAVE_GCC_COMPARE_AND_SWAP
#define HAVE_GPROF
#define HAVE_LOCALE
